@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::PERLANCAR::EnsurePrereqToSpec;
 
-our $DATE = '2015-12-17'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-12-27'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -60,11 +60,12 @@ sub setup_installer {
 
     # Rinci
     if ($self->check_dist_defines_rinci_meta || -f ".tag-implements-Rinci") {
-        $self->log_fatal(["Dist defines Rinci metadata or implements Rinci, but there is no DevelopRecommends prereq to Rinci"])
-            unless $self->_prereq_only_in($prereqs_hash, "Rinci", "develop", "recommends");
+        $self->log_fatal(["Dist defines Rinci metadata or implements Rinci, but there is no DevelopSuggests prereq to _SPEC::Rinci"])
+            unless $self->_prereq_only_in($prereqs_hash, "_SPEC::Rinci", "develop", "suggests");
     } else {
-        $self->log_fatal(["Dist does not define Rinci metadata, but there is a prereq to Rinci"])
-            unless $self->_prereq_none($prereqs_hash, "Rinci");
+        $self->log_fatal(["Dist does not define Rinci metadata, but there is a prereq to Rinci or _SPEC::Rinci"])
+            unless $self->_prereq_none($prereqs_hash, "Rinci") &&
+                $self->_prereq_none($prereqs_hash, "_SPEC::Rinci");
     }
 }
 
@@ -84,7 +85,7 @@ Dist::Zilla::Plugin::PERLANCAR::EnsurePrereqToSpec - Ensure prereq to spec modul
 
 =head1 VERSION
 
-This document describes version 0.02 of Dist::Zilla::Plugin::PERLANCAR::EnsurePrereqToSpec (from Perl distribution Dist-Zilla-Plugin-PERLANCAR-EnsurePrereqToSpec), released on 2015-12-17.
+This document describes version 0.03 of Dist::Zilla::Plugin::PERLANCAR::EnsurePrereqToSpec (from Perl distribution Dist-Zilla-Plugin-PERLANCAR-EnsurePrereqToSpec), released on 2016-12-27.
 
 =head1 SYNOPSIS
 
@@ -124,7 +125,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
